import uuid
from typing import Optional

from sqlalchemy import DateTime, func
from sqlmodel import SQLModel, Field
import datetime


class BaseModel(SQLModel):
    id: uuid.UUID = Field(default_factory=uuid.uuid4, primary_key=True)
    created_on: datetime = Field(
        default=None,
        sa_type=DateTime(timezone=True),
        sa_column_kwargs={"server_default": func.now()},
        nullable=False,
    )
    modified_on: Optional[datetime] = Field(
        default=None,
        sa_type=DateTime(timezone=True),
        sa_column_kwargs={"onupdate": func.now(), "server_default": func.now()},
    )


class ClientBaseModel(BaseModel):
    company: uuid.UUID = Field(index=True)



import json
from dataclasses import dataclass
from datetime import datetime
from enum import Enum


class Queue(str, Enum):
    integrations = "integrations"
    scouty = "scouty"
    feedmanager = "feedmanager"
    insights = "insights"
    billing = "billing"


@dataclass
class Event:
    event_type: str
    event: dict
    created_on: datetime = None

    def encode(self) -> bytes:
        self.created_on: datetime = datetime.now()
        return json.dumps(self.__dict__, default=str).encode()


@dataclass
class Message:
    body: Event
    queue: Queue
